@@ -27,11 +27,7 @@ from ironic.common import context as ironic_context
 from ironic.common import driver_factory
 from ironic.common import exception
 from ironic.common import hash_ring as hash
-from ironic.common.i18n import _
-from ironic.common.i18n import _LC
-from ironic.common.i18n import _LE
-from ironic.common.i18n import _LI
-from ironic.common.i18n import _LW
+from ironic.common.i18n import _, _LC, _LE, _LI, _LW
 from ironic.common import rpc
 from ironic.common import states
 from ironic.conductor import task_manager
@@ -51,7 +47,7 @@ class BaseConductorManager(object):
             host = CONF.host
         self.host = host
         self.topic = topic
-        self.notifier = rpc.get_notifier()
+        self.sensors_notifier = rpc.get_sensors_notifier()
         self._started = False
 
     def init_host(self, admin_context=None):
