@@ -50,13 +50,14 @@ class SSHValidateParametersTestCase(db_base.DbTestCase):
             driver='fake_ssh',
             driver_info=db_utils.get_test_ssh_info('password'))
         info = ssh._parse_driver_info(node)
-        self.assertIsNotNone(info.get('host'))
-        self.assertIsNotNone(info.get('username'))
-        self.assertIsNotNone(info.get('password'))
-        self.assertIsNotNone(info.get('port'))
-        self.assertIsNotNone(info.get('virt_type'))
-        self.assertIsNotNone(info.get('cmd_set'))
-        self.assertIsNotNone(info.get('uuid'))
+        self.assertEqual('1.2.3.4', info['host'])
+        self.assertEqual('admin', info['username'])
+        self.assertEqual('fake', info['password'])
+        self.assertEqual(22, info['port'])
+        self.assertEqual('virsh', info['virt_type'])
+        self.assertIsNotNone(info['cmd_set'])
+        self.assertEqual('1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
+                         info['uuid'])
 
     def test__parse_driver_info_good_key(self):
         # make sure we get back the expected things
@@ -65,13 +66,14 @@ class SSHValidateParametersTestCase(db_base.DbTestCase):
             driver='fake_ssh',
             driver_info=db_utils.get_test_ssh_info('key'))
         info = ssh._parse_driver_info(node)
-        self.assertIsNotNone(info.get('host'))
-        self.assertIsNotNone(info.get('username'))
-        self.assertIsNotNone(info.get('key_contents'))
-        self.assertIsNotNone(info.get('port'))
-        self.assertIsNotNone(info.get('virt_type'))
-        self.assertIsNotNone(info.get('cmd_set'))
-        self.assertIsNotNone(info.get('uuid'))
+        self.assertEqual('1.2.3.4', info['host'])
+        self.assertEqual('admin', info['username'])
+        self.assertEqual('--BEGIN PRIVATE ...blah', info['key_contents'])
+        self.assertEqual(22, info['port'])
+        self.assertEqual('virsh', info['virt_type'])
+        self.assertIsNotNone(info['cmd_set'])
+        self.assertEqual('1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
+                         info['uuid'])
 
     def test__parse_driver_info_good_file(self):
         # make sure we get back the expected things
@@ -85,13 +87,14 @@ class SSHValidateParametersTestCase(db_base.DbTestCase):
             driver='fake_ssh',
             driver_info=d_info)
         info = ssh._parse_driver_info(node)
-        self.assertIsNotNone(info.get('host'))
-        self.assertIsNotNone(info.get('username'))
-        self.assertIsNotNone(info.get('key_filename'))
-        self.assertIsNotNone(info.get('port'))
-        self.assertIsNotNone(info.get('virt_type'))
-        self.assertIsNotNone(info.get('cmd_set'))
-        self.assertIsNotNone(info.get('uuid'))
+        self.assertEqual('1.2.3.4', info['host'])
+        self.assertEqual('admin', info['username'])
+        self.assertEqual(key_path, info['key_filename'])
+        self.assertEqual(22, info['port'])
+        self.assertEqual('virsh', info['virt_type'])
+        self.assertIsNotNone(info['cmd_set'])
+        self.assertEqual('1be26c0b-03f2-4d2e-ae87-c02d7f33c123',
+                         info['uuid'])
 
     def test__parse_driver_info_bad_file(self):
         # A filename that doesn't exist errors.
@@ -156,16 +159,6 @@ class SSHValidateParametersTestCase(db_base.DbTestCase):
                           ssh._parse_driver_info,
                           node)
 
-    def test__normalize_mac_string(self):
-        mac_raw = "0A:1B-2C-3D:4F"
-        mac_clean = ssh._normalize_mac(mac_raw)
-        self.assertEqual("0a1b2c3d4f", mac_clean)
-
-    def test__normalize_mac_unicode(self):
-        mac_raw = u"0A:1B-2C-3D:4F"
-        mac_clean = ssh._normalize_mac(mac_raw)
-        self.assertEqual("0a1b2c3d4f", mac_clean)
-
     def test__parse_driver_info_with_custom_libvirt_uri(self):
         CONF.set_override('libvirt_uri', 'qemu:///foo', 'ssh')
         expected_base_cmd = "LC_ALL=C /usr/bin/virsh --connect qemu:///foo"
@@ -216,8 +209,7 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
 
     @mock.patch.object(utils, 'ssh_connect', autospec=True)
     def test__get_connection_exception(self, ssh_connect_mock):
-        ssh_connect_mock.side_effect = iter(
-            [exception.SSHConnectFailed(host='fake')])
+        ssh_connect_mock.side_effect = exception.SSHConnectFailed(host='fake')
         self.assertRaises(exception.SSHConnectFailed,
                           ssh._get_connection,
                           self.node)
@@ -332,8 +324,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
         cmd_to_exec = "%s %s" % (info['cmd_set']['base_cmd'],
                                  info['cmd_set']['get_node_macs'])
         cmd_to_exec = cmd_to_exec.replace('{_NodeName_}', 'NodeName')
-        exec_ssh_mock.side_effect = iter([('NodeName', ''),
-                                          ('52:54:00:cf:2d:31', '')])
+        exec_ssh_mock.side_effect = [('NodeName', ''),
+                                     ('52:54:00:cf:2d:31', '')]
         expected = [mock.call(self.sshclient, ssh_cmd),
                     mock.call(self.sshclient, cmd_to_exec)]
 
@@ -348,8 +340,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
         self.config(group='ssh', get_vm_name_retry_interval=0)
         info = ssh._parse_driver_info(self.node)
         info['macs'] = ["11:11:11:11:11:11", "22:22:22:22:22:22"]
-        exec_ssh_mock.side_effect = iter([('NodeName', ''),
-                                          ('52:54:00:cf:2d:31', '')] * 2)
+        exec_ssh_mock.side_effect = ([('NodeName', ''),
+                                      ('52:54:00:cf:2d:31', '')] * 2)
 
         ssh_cmd = "%s %s" % (info['cmd_set']['base_cmd'],
                              info['cmd_set']['list_all'])
@@ -371,10 +363,10 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
         self.config(group='ssh', get_vm_name_retry_interval=0)
         info = ssh._parse_driver_info(self.node)
         info['macs'] = ["11:11:11:11:11:11", "22:22:22:22:22:22"]
-        exec_ssh_mock.side_effect = iter([('NodeName', ''),
-                                          ('', ''),
-                                          ('NodeName', ''),
-                                          ('11:11:11:11:11:11', '')])
+        exec_ssh_mock.side_effect = [('NodeName', ''),
+                                     ('', ''),
+                                     ('NodeName', ''),
+                                     ('11:11:11:11:11:11', '')]
 
         ssh_cmd = "%s %s" % (info['cmd_set']['base_cmd'],
                              info['cmd_set']['list_all'])
@@ -402,8 +394,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
                                  info['cmd_set']['get_node_macs'])
         cmd_to_exec = cmd_to_exec.replace('{_NodeName_}', 'NodeName')
 
-        exec_ssh_mock.side_effect = iter(
-            [('NodeName', ''), processutils.ProcessExecutionError])
+        exec_ssh_mock.side_effect = [('NodeName', ''),
+                                     processutils.ProcessExecutionError]
         expected = [mock.call(self.sshclient, ssh_cmd),
                     mock.call(self.sshclient, cmd_to_exec)]
 
@@ -421,8 +413,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
         info = ssh._parse_driver_info(self.node)
         info['macs'] = ["11:11:11:11:11:11", "52:54:00:cf:2d:31"]
 
-        get_power_status_mock.side_effect = iter([states.POWER_OFF,
-                                                  states.POWER_ON])
+        get_power_status_mock.side_effect = [states.POWER_OFF,
+                                             states.POWER_ON]
         get_hosts_name_mock.return_value = "NodeName"
         expected = [mock.call(self.sshclient, info),
                     mock.call(self.sshclient, info)]
@@ -444,8 +436,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
                             exec_ssh_mock):
         info = ssh._parse_driver_info(self.node)
         info['macs'] = ["11:11:11:11:11:11", "52:54:00:cf:2d:31"]
-        get_power_status_mock.side_effect = iter([states.POWER_OFF,
-                                                 states.POWER_OFF])
+        get_power_status_mock.side_effect = ([states.POWER_OFF,
+                                              states.POWER_OFF])
         get_hosts_name_mock.return_value = "NodeName"
         expected = [mock.call(self.sshclient, info),
                     mock.call(self.sshclient, info)]
@@ -469,8 +461,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
         info['macs'] = ["11:11:11:11:11:11", "52:54:00:cf:2d:31"]
 
         exec_ssh_mock.side_effect = processutils.ProcessExecutionError
-        get_power_status_mock.side_effect = iter([states.POWER_OFF,
-                                                  states.POWER_ON])
+        get_power_status_mock.side_effect = ([states.POWER_OFF,
+                                              states.POWER_ON])
         get_hosts_name_mock.return_value = "NodeName"
 
         cmd_to_exec = "%s %s" % (info['cmd_set']['base_cmd'],
@@ -492,8 +484,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
                              get_power_status_mock, exec_ssh_mock):
         info = ssh._parse_driver_info(self.node)
         info['macs'] = ["11:11:11:11:11:11", "52:54:00:cf:2d:31"]
-        get_power_status_mock.side_effect = iter([states.POWER_ON,
-                                                  states.POWER_OFF])
+        get_power_status_mock.side_effect = [states.POWER_ON,
+                                             states.POWER_OFF]
         get_hosts_name_mock.return_value = "NodeName"
         expected = [mock.call(self.sshclient, info),
                     mock.call(self.sshclient, info)]
@@ -515,8 +507,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
                              get_power_status_mock, exec_ssh_mock):
         info = ssh._parse_driver_info(self.node)
         info['macs'] = ["11:11:11:11:11:11", "52:54:00:cf:2d:31"]
-        get_power_status_mock.side_effect = iter([states.POWER_ON,
-                                                  states.POWER_ON])
+        get_power_status_mock.side_effect = [states.POWER_ON,
+                                             states.POWER_ON]
         get_hosts_name_mock.return_value = "NodeName"
         expected = [mock.call(self.sshclient, info),
                     mock.call(self.sshclient, info)]
@@ -539,8 +531,8 @@ class SSHPrivateMethodsTestCase(db_base.DbTestCase):
         info = ssh._parse_driver_info(self.node)
         info['macs'] = ["11:11:11:11:11:11", "52:54:00:cf:2d:31"]
         exec_ssh_mock.side_effect = processutils.ProcessExecutionError
-        get_power_status_mock.side_effect = iter([states.POWER_ON,
-                                                 states.POWER_OFF])
+        get_power_status_mock.side_effect = [states.POWER_ON,
+                                             states.POWER_OFF]
         get_hosts_name_mock.return_value = "NodeName"
 
         cmd_to_exec = "%s %s" % (info['cmd_set']['base_cmd'],
@@ -569,8 +561,7 @@ class SSHDriverTestCase(db_base.DbTestCase):
 
     @mock.patch.object(utils, 'ssh_connect', autospec=True)
     def test__validate_info_ssh_connect_failed(self, ssh_connect_mock):
-        ssh_connect_mock.side_effect = iter(
-            [exception.SSHConnectFailed(host='fake')])
+        ssh_connect_mock.side_effect = exception.SSHConnectFailed(host='fake')
         with task_manager.acquire(self.context, self.node.uuid,
                                   shared=False) as task:
             self.assertRaises(exception.InvalidParameterValue,
@@ -783,6 +774,34 @@ class SSHDriverTestCase(db_base.DbTestCase):
                         '--boot1 net') % fake_name
         mock_exc.assert_called_once_with(mock.ANY, expected_cmd)
 
+    @mock.patch.object(ssh, '_get_power_status', autospec=True)
+    @mock.patch.object(ssh, '_get_connection', autospec=True)
+    @mock.patch.object(ssh, '_get_hosts_name_for_node', autospec=True)
+    @mock.patch.object(ssh, '_ssh_execute', autospec=True)
+    def test_management_interface_set_boot_device_vbox_with_power_on(
+            self, mock_exc, mock_h, mock_get_conn, mock_get_power):
+        fake_name = 'fake-name'
+        mock_h.return_value = fake_name
+        mock_get_conn.return_value = self.sshclient
+        # NOTE(jroll) _power_off calls _get_power_state twice
+        mock_get_power.side_effect = [
+            states.POWER_ON, states.POWER_ON, states.POWER_OFF
+        ]
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            task.node['driver_info']['ssh_virt_type'] = 'vbox'
+            task.node['driver_info']['vbox_use_headless'] = True
+            self.driver.management.set_boot_device(task, boot_devices.PXE)
+
+        expected_cmds = [
+            mock.call(mock.ANY,
+                      'LC_ALL=C /usr/bin/VBoxManage '
+                      'controlvm %s poweroff' % fake_name),
+            mock.call(mock.ANY,
+                      'LC_ALL=C /usr/bin/VBoxManage '
+                      'modifyvm %s --boot1 net' % fake_name)
+        ]
+        self.assertEqual(expected_cmds, mock_exc.call_args_list)
+
     @mock.patch.object(ssh, '_get_connection', autospec=True)
     @mock.patch.object(ssh, '_get_hosts_name_for_node', autospec=True)
     @mock.patch.object(ssh, '_ssh_execute', autospec=True)
@@ -1017,6 +1036,40 @@ class SSHDriverTestCase(db_base.DbTestCase):
                         "vm-shutdown uuid=fakevm force=true")
         mock_exc.assert_called_once_with(mock.ANY, expected_cmd)
 
+    @mock.patch.object(ssh, '_get_connection', autospec=True)
+    @mock.patch.object(ssh, '_get_hosts_name_for_node', autospec=True)
+    @mock.patch.object(ssh, '_ssh_execute', autospec=True)
+    @mock.patch.object(ssh, '_get_power_status', autospec=True)
+    def test_start_command_vbox(self, mock_power, mock_exc, mock_h,
+                                mock_get_conn):
+        mock_power.side_effect = [states.POWER_OFF, states.POWER_ON]
+        nodename = 'fakevm'
+        mock_h.return_value = nodename
+        mock_get_conn.return_value = self.sshclient
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            task.node['driver_info']['ssh_virt_type'] = 'vbox'
+            self.driver.power.set_power_state(task, states.POWER_ON)
+        expected_cmd = 'LC_ALL=C /usr/bin/VBoxManage startvm fakevm'
+        mock_exc.assert_called_once_with(mock.ANY, expected_cmd)
+
+    @mock.patch.object(ssh, '_get_connection', autospec=True)
+    @mock.patch.object(ssh, '_get_hosts_name_for_node', autospec=True)
+    @mock.patch.object(ssh, '_ssh_execute', autospec=True)
+    @mock.patch.object(ssh, '_get_power_status', autospec=True)
+    def test_start_command_vbox_headless(self, mock_power, mock_exc, mock_h,
+                                         mock_get_conn):
+        mock_power.side_effect = [states.POWER_OFF, states.POWER_ON]
+        nodename = 'fakevm'
+        mock_h.return_value = nodename
+        mock_get_conn.return_value = self.sshclient
+        with task_manager.acquire(self.context, self.node.uuid) as task:
+            task.node['driver_info']['ssh_virt_type'] = 'vbox'
+            task.node['driver_info']['vbox_use_headless'] = True
+            self.driver.power.set_power_state(task, states.POWER_ON)
+        expected_cmd = ('LC_ALL=C /usr/bin/VBoxManage '
+                        'startvm fakevm --type headless')
+        mock_exc.assert_called_once_with(mock.ANY, expected_cmd)
+
     def test_management_interface_validate_good(self):
         with task_manager.acquire(self.context, self.node.uuid) as task:
             task.driver.management.validate(task)
