@@ -2,6 +2,7 @@
 
 PROJECT_NAME=${PROJECT_NAME:-ironic}
 CFGFILE_NAME=${PROJECT_NAME}.conf.sample
+OSLO_CFGFILE_OPTION=${OSLO_CFGFILE_OPTION:-tools/config/ironic-config-generator.conf}
 
 if [ -e etc/${PROJECT_NAME}/${CFGFILE_NAME} ]; then
     CFGFILE=etc/${PROJECT_NAME}/${CFGFILE_NAME}
@@ -15,7 +16,7 @@ fi
 TEMPDIR=`mktemp -d /tmp/${PROJECT_NAME}.XXXXXX`
 trap "rm -rf $TEMPDIR" EXIT
 
-tools/config/generate_sample.sh -b ./ -p ${PROJECT_NAME} -o ${TEMPDIR}
+oslo-config-generator --config-file=${OSLO_CFGFILE_OPTION} --output-file ${TEMPDIR}/${CFGFILE_NAME}
 if [ $? != 0 ]
 then
     exit 1
@@ -24,6 +25,6 @@ fi
 if ! diff -u ${TEMPDIR}/${CFGFILE_NAME} ${CFGFILE}
 then
    echo "${0##*/}: ${PROJECT_NAME}.conf.sample is not up to date."
-   echo "${0##*/}: Please run ${0%%${0##*/}}generate_sample.sh."
+   echo "${0##*/}: Please run oslo-config-generator --config-file=${OSLO_CFGFILE_OPTION}"
    exit 1
 fi
